==> cpm-1.0.0.tar.gz: cpm-1.0.0/src/cpm_collective.h <==
#ifndef CPM_COLLECTIVE_H_
#define CPM_COLLECTIVE_H_

/*!
 * \defgroup Collective Collective
 * \brief Heterogeneous implementations of MPI collective operations.
 * \{
 */

/*!
 * \brief The global instance of the CPM model for use in the optimized scatter/gather.
 * \details Must be initialized by \ref CPM_model_initialize and destroyed by \ref CPM_model_finalize on all processes. 
 */
extern CPM_model* CPM_model_instance;

/*!
 * \brief Initializes the instances of the CPM model (\ref CPM_model_instance) on all processes in the communicatior.
 * \param comm MPI communicator 
 * \param model CPM model (significant only at root)
 */
void CPM_model_initialize(MPI_Comm comm, CPM_model* model);

/*!
 * \brief Destroys the instances of the CPM model (\ref CPM_model_instance) on all processes in the communicatior.
 */
void CPM_model_finalize(MPI_Comm comm);

/*!
 * \brief Optimized MPI_Scatter.
 * \details \ref CPM_model_instance must be initialized.
 */
int CPM_Scatter_opt(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype, 
	int root, MPI_Comm comm);

/*!
 * \brief Optimized MPI_Gather.
 * \details \ref CPM_model_instance must be initialized.
 */
int CPM_Gather_opt(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*!
 * \brief The global instance of Hockney model for use in the optimized scatter/gather.
 * \details Must be initialized by \ref Hockney_initialize and destroyed by \ref Hockney_finalize on all processes. 
 */
extern Hockney_model* Hockney_model_instance;

/*!
 * \brief Initializes the instances of the Hockney model (\ref Hockney_model_instance) on all processes in the communicatior.
 * \param comm MPI communicator 
 * \param model Hockney model (significant only at root)
 */
void Hockney_initialize(MPI_Comm comm, Hockney_model* model);

/*!
 * \brief Destroys the instances of the Hockney model (\ref Hockney_model_instance) on all processes in the communicatior.
 */
void Hockney_finalize(MPI_Comm comm);

/*!
 * \brief Optimized binomial MPI_Scatter based on the Hockney model.
 * \details \ref Hockney_model_instance must be initialized.
 */
int CPM_Scatter_binomial_opt(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype, 
	int root, MPI_Comm comm);

/*!
 * \brief Corrupted binomial MPI_Scatter based on the Hockney model.
 * \details \ref Hockney_model_instance must be initialized.
 */
int CPM_Scatter_binomial_cor(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype, 
	int root, MPI_Comm comm);

/*!
 * \brief Optimized binomial MPI_Gather based on the Hockney model.
 * \details \ref Hockney_model_instance must be initialized.
 */
int CPM_Gather_binomial_opt(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*!
 * \brief Corrupted binomial MPI_Gather based on the Hockney model.
 * \details \ref Hockney_model_instance must be initialized.
 */
int CPM_Gather_binomial_cor(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*!
 * \brief The global instance of the optimized/corrupted communicator for use in the optimized/corrupted scatter/gather.
 * \details Must be initialized by \ref CPM_p2p_initialize and destroyed by \ref CPM_p2p_finalize on all processes. 
 */
extern MPI_Comm CPM_comm_instance;

/*!
 * \brief Initializes the instances of the optimized/corrupted communicator (\ref CPM_comm_instance) on all processes in the communicatior.
 * \param comm basic communicator
 * \param root root in the resulted communicator
 * \param opt optimized (1) or corrupted (0) communicator
 */
void CPM_p2p_initialize(MPI_Comm comm, int root, int opt);

/*!
 * \brief Destroys the instances of the p2p execution times (\ref CPM_comm_instance) on all processes in the communicatior.
 */
void CPM_p2p_finalize(MPI_Comm comm);

/*!
 * \brief Binomial MPI_Scatter based on the reordered comm \ref CPM_comm_instance.
 * \details \ref CPM_comm_instance must be initialized.
 */
int CPM_Scatter_binomial(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype, 
	int root, MPI_Comm comm);

/*!
 * \}
 */

#endif /*CPM_COLLECTIVE_H_*/

==> cpm-1.0.1.tar.gz: cpm-1.0.1/src/cpm_collective.h <==
#ifndef CPM_COLLECTIVE_H_
#define CPM_COLLECTIVE_H_

/*!
 * \defgroup Collective Collective
 * \brief Heterogeneous implementations of MPI collective operations.
 * \{
 */

/*!
 * \brief The global instance of the LMO model for use in the optimized scatter/gather.
 * \details Must be initialized by \ref LMO_initialize and destroyed by \ref LMO_finalize on all processes. 
 */
extern LMO_model* LMO_instance;

/*!
 * \brief Initializes the instances of the LMO model (\ref LMO_instance) on all processes in the communicatior.
 * \param comm MPI communicator 
 * \param model LMO model (significant only at root)
 */
void LMO_initialize(MPI_Comm comm, LMO_model* model);

/*!
 * \brief Destroys the instances of the LMO model (\ref LMO_instance) on all processes in the communicatior.
 */
void LMO_finalize(MPI_Comm comm);

/*!
 * \brief Optimized linear MPI_Scatter.
 * \details \ref LMO_instance must be initialized.
 */
int CPM_Scatter_linear_opt(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype, 
	int root, MPI_Comm comm);

/*!
 * \brief Optimized linear MPI_Gather.
 * \details \ref LMO_instance must be initialized.
 */
int CPM_Gather_linear_opt(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*!
 * \brief The global instance of Hockney model for use in the optimized scatter/gather.
 * \details Must be initialized by \ref Hockney_initialize and destroyed by \ref Hockney_finalize on all processes. 
 */
extern Hockney_model* Hockney_model_instance;

/*!
 * \brief Initializes the instances of the Hockney model (\ref Hockney_model_instance) on all processes in the communicatior.
 * \param comm MPI communicator 
 * \param model Hockney model (significant only at root)
 */
void Hockney_initialize(MPI_Comm comm, Hockney_model* model);

/*!
 * \brief Destroys the instances of the Hockney model (\ref Hockney_model_instance) on all processes in the communicatior.
 */
void Hockney_finalize(MPI_Comm comm);

/*!
 * \brief Optimized binomial MPI_Scatter based on the Hockney model.
 * \details \ref Hockney_model_instance must be initialized.
 */
int CPM_Scatter_binomial_opt(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype, 
	int root, MPI_Comm comm);

/*!
 * \brief Corrupted binomial MPI_Scatter based on the Hockney model.
 * \details \ref Hockney_model_instance must be initialized.
 */
int CPM_Scatter_binomial_cor(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype, 
	int root, MPI_Comm comm);

/*!
 * \brief Optimized binomial MPI_Gather based on the Hockney model.
 * \details \ref Hockney_model_instance must be initialized.
 */
int CPM_Gather_binomial_opt(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*!
 * \brief Corrupted binomial MPI_Gather based on the Hockney model.
 * \details \ref Hockney_model_instance must be initialized.
 */
int CPM_Gather_binomial_cor(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*!
 * \brief The global instance of the optimized/corrupted communicator for use in the optimized/corrupted scatter/gather.
 * \details Must be initialized by \ref CPM_p2p_initialize and destroyed by \ref CPM_p2p_finalize on all processes. 
 */
extern MPI_Comm CPM_comm_instance;

/*!
 * \brief Initializes the instances of the optimized/corrupted communicator (\ref CPM_comm_instance) on all processes in the communicatior.
 * \param comm basic communicator
 * \param root root in the resulted communicator
 * \param opt optimized (1) or corrupted (0) communicator
 */
void CPM_p2p_initialize(MPI_Comm comm, int root, int opt);

/*!
 * \brief Destroys the instances of the p2p execution times (\ref CPM_comm_instance) on all processes in the communicatior.
 */
void CPM_p2p_finalize(MPI_Comm comm);

/*!
 * \brief Binomial MPI_Scatter based on the reordered comm \ref CPM_comm_instance.
 * \details \ref CPM_comm_instance must be initialized.
 */
int CPM_Scatter_binomial(void* sendbuf, int sendcount, MPI_Datatype sendtype, 
	void* recvbuf, int recvcount, MPI_Datatype recvtype, 
	int root, MPI_Comm comm);

/*!
 * \}
 */

#endif /*CPM_COLLECTIVE_H_*/
